@@ -17,6 +17,7 @@
 #include <map>
 #include <cassert>
 
+#include "test_macros.h"
 #include "min_allocator.h"
 #include "private_constructor.hpp"
 #include "is_transparent.h"
@@ -297,7 +298,7 @@ int main()
     }
     }
 #endif
-#if _LIBCPP_STD_VER > 11
+#if TEST_STD_VER > 11
     {
     typedef std::pair<const int, double> V;
     typedef std::map<int, double, std::less<>> M;
