@@ -7,6 +7,8 @@
 //
 //===----------------------------------------------------------------------===//
 
+// UNSUPPORTED: c++98, c++03
+
 // <set>
 
 // class multiset
@@ -20,7 +22,6 @@
 
 int main()
 {
-#ifndef _LIBCPP_HAS_NO_GENERALIZED_INITIALIZERS
     {
     typedef std::multiset<int> C;
     typedef C::value_type V;
@@ -36,8 +37,6 @@ int main()
     assert(*++i == V(5));
     assert(*++i == V(6));
     }
-#endif  // _LIBCPP_HAS_NO_GENERALIZED_INITIALIZERS
-#if TEST_STD_VER >= 11
     {
     typedef std::multiset<int, std::less<int>, min_allocator<int>> C;
     typedef C::value_type V;
@@ -53,5 +52,4 @@ int main()
     assert(*++i == V(5));
     assert(*++i == V(6));
     }
-#endif
 }
