@@ -282,4 +282,20 @@ int main()
     test2<S>();
     }
 #endif
+
+	{ // test replacing into self
+    typedef std::string S;
+	S s_short = "123/";
+	S s_long  = "Lorem ipsum dolor sit amet, consectetur/";
+
+	s_short.replace(s_short.begin(), s_short.begin(), s_short.c_str());
+	assert(s_short == "123/123/");
+	s_short.replace(s_short.begin(), s_short.begin(), s_short.c_str());
+	assert(s_short == "123/123/123/123/");
+	s_short.replace(s_short.begin(), s_short.begin(), s_short.c_str());
+	assert(s_short == "123/123/123/123/123/123/123/123/");
+
+	s_long.replace(s_long.begin(), s_long.begin(), s_long.c_str());
+	assert(s_long == "Lorem ipsum dolor sit amet, consectetur/Lorem ipsum dolor sit amet, consectetur/");
+	}
 }
