@@ -33,7 +33,7 @@
 //   the construction of types using an allocator. This type is used to communicate
 //   between the test author, the containers allocator, and the types
 //   being constructed by the container.
-//   The controllers primary functions are:
+//   The controller's primary functions are:
 //     1. Allow calls to 'a.construct(p, args...)' to be checked by a test.
 //        The test uses 'cc->expect<Args...>()' to specify that the allocator
 //        should expect one call to 'a.construct' with the specified argument
@@ -234,6 +234,19 @@ inline ConstructController* getConstructController() {
   return &c;
 }
 
+template <class ...Args>
+struct ExpectConstructGuard {
+  ExpectConstructGuard(int N)  {
+    auto CC = getConstructController();
+    assert(!CC->unchecked());
+    CC->expect<Args...>(N);
+  }
+
+  ~ExpectConstructGuard() {
+    assert(!getConstructController()->unchecked());
+  }
+};
+
 //===----------------------------------------------------------------------===//
 //                       ContainerTestAllocator
 //===----------------------------------------------------------------------===//
@@ -366,7 +379,7 @@ struct CopyInsertable {
 
   CopyInsertable(CopyInsertable&& other) : CopyInsertable(other) {}
 
-  // Forgive pair for not downcasting this to an lvalue it its constructors.
+  // Forgive pair for not downcasting this to an lvalue in its constructors.
   CopyInsertable(CopyInsertable const && other) : CopyInsertable(other) {}
 
 
@@ -417,7 +430,12 @@ namespace std {
       return arg.data;
     }
   };
-
+  template <class T, class Alloc>
+  class vector;
+  template <class T, class Alloc>
+  class deque;
+  template <class T, class Alloc>
+  class list;
   template <class _Key, class _Value, class _Less, class _Alloc>
   class map;
   template <class _Key, class _Value, class _Less, class _Alloc>
@@ -444,6 +462,13 @@ _LIBCPP_END_NAMESPACE_STD
 // TCT - Test container type
 namespace TCT {
 
+template <class T = CopyInsertable<1>>
+using vector = std::vector<T, ContainerTestAllocator<T, T> >;
+template <class T = CopyInsertable<1>>
+using deque = std::deque<T, ContainerTestAllocator<T, T> >;
+template <class T = CopyInsertable<1>>
+using list = std::list<T, ContainerTestAllocator<T, T> >;
+
 template <class Key = CopyInsertable<1>, class Value = CopyInsertable<2>,
           class ValueTp = std::pair<const Key, Value> >
 using unordered_map =
@@ -488,5 +513,4 @@ using multiset =
 
 } // end namespace TCT
 
-
 #endif // SUPPORT_CONTAINER_TEST_TYPES_H
